@@ -46,16 +46,14 @@ def gen_gs_project(
     assert gen_project_dir.exists()
     assert gen_project_dir.is_dir()
     assert (gen_project_dir / 'src').exists() and (gen_project_dir / 'src').is_dir()
-    # Ad-hoc sanity checks that docs folder contains all sub-dirs and nested files
+
+    # sanity checks on docs folder
     assert (gen_project_dir / 'docs').exists()
+    assert (gen_project_dir / 'docs').is_dir()
+
+    # sanity check that cleanup of docs folder is done
     assert not (gen_project_dir / 'docs-mkdocs').exists()
     assert not (gen_project_dir / 'docs-sphinx').exists()
-    assert (gen_project_dir / 'docs').is_dir()
-    assert (gen_project_dir / 'docs' / 'assets').exists()
-    assert (gen_project_dir / 'docs' / 'assets').is_dir()
-    assert (gen_project_dir / 'docs' / 'dev_guides').exists()
-    assert (gen_project_dir / 'docs' / 'dev_guides' / 'docker.md').exists()
-    assert (gen_project_dir / 'docs' / 'dev_guides' / 'docker.md').is_file()
 
     ## Logging file created - Assertions ##
     from cookiecutter_python._logging_config import FILE_TARGET_LOGS
@@ -139,11 +137,18 @@ def compare_file_content():
         runtime_file_content = runtime_file.read_text().splitlines()
         snap_file_content = snap_file.read_text().splitlines()
 
+        # find common parts of a above Path objects
+        common_parts = set(runtime_file.parts).intersection(set(snap_file.parts))
+
+        # use existing part to order the set
+        ordered_parts: t.Tuple = tuple([x for x in snap_file.parts if x in common_parts])
+
         for line_index, line_pair in enumerate(zip(runtime_file_content, snap_file_content)):
             assert line_pair[0] == line_pair[1], (
                 f"File: {runtime_file.relative_to(runtime_file.parent)} has different content at Runtime than in Snapshot\n"
+                f"Relative (sub) path: {Path(*ordered_parts).resolve()}\n"
                 f"Line Index: {line_index}\n"
-                f"Line Runtime: {line_pair[0]}\n"
+                f"Line Runtime : {line_pair[0]}\n"
                 f"Line Snapshot: {line_pair[1]}\n"
             )
         assert len(runtime_file_content) == len(snap_file_content)
@@ -153,7 +158,7 @@ def compare_file_content():
 
 @pytest.fixture(scope='module')
 def file_gen():
-    def _file_gen(runtime_relative_paths_set: t.Set[Path]) -> t.Iterator[t.Tuple[Path, Path]]:
+    def _file_gen(runtime_relative_paths_set: t.Set[Path]) -> t.Iterator[Path]:
         for relative_path in [
             x
             for x in sorted(
@@ -203,12 +208,6 @@ def test_gs_matches_runtime(
     import sys
 
     running_on_windows: bool = sys.platform.startswith("win")
-    # exception misbehaviour fixed on Windows?
-    import os
-
-    has_developer_fixed_windows_mishap: bool = (
-        os.environ.get("BUG_LOG_DEL_WIN") != "permission_error"
-    )
 
     # This is useful for local development, to make the tests more reliable
     snap_relative_paths_set = set(
@@ -225,6 +224,7 @@ def test_gs_matches_runtime(
                             'settings.json',
                             '.tox',
                             '.pytest_cache',
+                            'del-env',
                         }
                         for p in x.parts
                     ]
@@ -234,9 +234,7 @@ def test_gs_matches_runtime(
     )
     snap_relative_paths_set = set([x for x in snap_relative_paths_set if x.name != 'reqs.txt'])
 
-    if has_developer_fixed_windows_mishap:
-        assert runtime_relative_paths_set == snap_relative_paths_set
-    elif running_on_windows:  # there is a log mishappening that we exists on windows
+    if running_on_windows:  # there is a log mishappening that we exists on windows
         from cookiecutter_python._logging_config import (
             FILE_TARGET_LOGS as LOG_FILE_NAME,
         )
